==> treebeard-0.0.11.tar.gz: treebeard-0.0.11/treebeard/treebeard.py <==
#! python
import warnings
import click
import shutil
import time
import os
import base64
import tarfile
import json
import os.path
import subprocess
import secrets
import configparser
import requests
import timeago
import datetime
from dateutil import parser

# from Firebase import auth
from halo import Halo
from treebeard.helper import get_treebeard_env

treebeard_env = get_treebeard_env()
local_url = 'http://localhost:8080/notebooks/'
remote_url = "https://scheduler-cvee2224cq-ew.a.run.app/notebooks/"

warnings.filterwarnings(
    "ignore", "Your application has authenticated using end user credentials")

# Instantiates a client
dir_path = os.path.dirname(os.path.realpath(__file__))


def set_credentials(email):
    """Create user credentials"""
    key = secrets.token_urlsafe(16)
    config = configparser.RawConfigParser()
    config = configparser.RawConfigParser()
    config.add_section('credentials')
    config.set('credentials', 'TREEBEARD_API_KEY', key)
    config.set('credentials', 'TREEBEARD_EMAIL', email)
    with open('credentials.cfg', 'w') as configfile:
        config.write(configfile)
    os.environ["TREEBEARD_API_KEY"] = key
    os.environ["TREEBEARD_EMAIL"] = email
    click.echo(f'User credentials saved. Email: {email}, API key: {key}')
    return key, email

# Scheduler gives token
# Scheduler takes token and resolves with user ID and knows it is the person


def fetch_credentials():
    """
    Checks for user credentials and returns user email and API key
    """
    # Does credentials.cfg exist and if it does, can we read the API key
    config = configparser.RawConfigParser()
    creds_path = 'credentials.cfg'
    try:
        os.path.isfile(creds_path)
        config.read(creds_path)
        key = config.get('credentials', 'TREEBEARD_API_KEY')
        email = config.get('credentials', 'TREEBEARD_EMAIL')
        click.echo('Connecting to your account.')
    except:
        click.echo(f"No credentials found - please run: treebeard configure")
    return key, email


def firebase_auth(key, email):
    """Login or create account in a webpage"""
    # additional_claims = {
    #     'email': 'myemail@me.com'
    # }
    # custom_token = auth.create_custom_token('myapikey', additional_claims)

    # click.launch(
    #     f'https://treebeard.io/app/login?email={email}&key=&{key}')
    click.echo('Webpage launch')
    return


@click.group()
def cli():
    pass
    # click.echo('Debug mode is %s' % ('on' if debug else 'off'))

    # @cli.command()
    # @click.option('--email', prompt='Your email:')
    # def configure(email):
    #     """ Set initial credentials"""
    #     set_credentials(email)

    # @cli.command()
    # def init():
    #     """Connect to Treebeard account (browser popup or CLI login)
    #     """
    #     # Check if local credentials exist
    #     key, email = fetch_credentials()
    #     # Authorise User Account with Firebase
    #     firebase_auth(key, email)
    #     click.echo(f'Account initialised for {email}, key: {key}')
    #     return


# @cli.command()
# @click.option('--file', '-f', 'filename', default=None, type=click.Path(exists=True),
#               help='Specify notebook to see logs')
# def logs(filename):
#     """
#     See all actions and deployment results
#     """
#     if filename:
#         click.echo(f'Historical deployments for {filename}:')
#     else:
#         click.echo('Historical deployments for all notebooks:')

@cli.command()
@click.option('t', '--hourly', flag_value='hourly', help='Run notebook hourly')
@click.option('t', '--daily', default=True, flag_value='daily', help='Run notebook daily')
@click.option('t', '--weekly', flag_value='weekly', help='Run notebook weekly')
@click.option('t', '--quarter-hourly', flag_value='quarter-hourly', help='Run quarter-hourly')
def run(t):
    """
    Run a notebook and optionally schedule it to run periodically
    """
    notebook_name = treebeard_env['notebook_id']
    endpoint = f"{remote_url}{notebook_name}"

    spinner = Halo(text='requesting run', spinner='dots')
    spinner.start()
    archive_filename = '/tmp/treebeard_upload.tgz'
    with tarfile.open(archive_filename, "w:gz") as tar:
        tar.add(os.getcwd(), arcname=os.path.basename(os.path.sep))

    response = requests.post(
        endpoint, files={'repo': open('/tmp/treebeard_upload.tgz', 'rb')})

    spinner.stop()

    json_data = json.loads(response.text)
    click.echo(f"Run has been accepted! {json_data['admin_url']}")


@cli.command()
def cancel():
    """Cancels the current notebook build and schedule"""
    notebook_name = treebeard_env['notebook_id']
    endpoint = f"{remote_url}{notebook_name}"

    spinner = Halo(text='cancelling', spinner='dots')
    click.echo(f"Cancelling {notebook_name}")
    spinner.start()
    requests.delete(endpoint)
    spinner.stop()
    click.echo(f"cancelled {notebook_name}!`")


@cli.command()
def status():
    """Show the status of the current notebook"""
    notebook_name = treebeard_env['notebook_id']
    endpoint = f"{remote_url}{notebook_name}"

    response = requests.get(endpoint)
    json_data = json.loads(response.text)
    click.echo(f"Notebook: {notebook_name}")
    if len(json_data) == 0:
        click.echo(
            'This notebook has not been run. Try running it with `treebeard run`')
        return
    click.echo('Recent runs:')
    for run in json_data:
        now = parser.isoparse(datetime.datetime.utcnow().isoformat() + 'Z')
        start_time = parser.isoparse(run['start_time'])
        time_string = timeago.format(start_time, now=now)
        click.echo(f"{run['url']} {time_string}")


@cli.command()
def version():
    import pkg_resources  # part of setuptools
    version = pkg_resources.require("treebeard")[0].version
    click.echo(version)


@cli.command()
def info():
    click.echo(treebeard_env)

==> treebeard-0.0.14.tar.gz: treebeard-0.0.14/treebeard/treebeard.py <==
#! python
import warnings
import click
import shutil
import time
import os
import base64
import tarfile
import json
import os.path
import subprocess
import secrets
import configparser
import requests
import timeago
import datetime
from dateutil import parser

# from Firebase import auth
from halo import Halo
from treebeard.helper import get_treebeard_env

treebeard_env = get_treebeard_env()
local_url = 'http://localhost:8080/notebooks/'
remote_url = "https://scheduler-cvee2224cq-ew.a.run.app/notebooks/"

warnings.filterwarnings(
    "ignore", "Your application has authenticated using end user credentials")

# Instantiates a client
dir_path = os.path.dirname(os.path.realpath(__file__))


def set_credentials(email, key):
    """Create user credentials"""
    # key = secrets.token_urlsafe(16)
    config = configparser.RawConfigParser()
    config.add_section('credentials')
    config.set('credentials', 'TREEBEARD_EMAIL', email)
    # Project id is last 10 numbers of hash of email
    project_id = str(hash(email))[-10:]
    config.set('credentials', 'TREEBEARD_PROJECT_ID', project_id)
    config.set('credentials', 'TREEBEARD_API_KEY', key)
    with open('credentials.cfg', 'w') as configfile:
        config.write(configfile)
    os.environ["TREEBEARD_EMAIL"] = email
    os.environ["TREEBEARD_PROJECT_ID"] = project_id
    os.environ["TREEBEARD_API_KEY"] = key
    click.echo(
        f'User credentials saved.\nEmail: {email}\nProject ID: {project_id}\nAPI key: {key}')
    return

# Scheduler gives token
# Scheduler takes token and resolves with user ID and knows it is the person


def fetch_credentials():
    """
    Checks for user credentials and returns user email and API key
    """
    # Does credentials.cfg exist and if it does, can we read the API key
    config = configparser.RawConfigParser()
    creds_path = 'credentials.cfg'
    try:
        os.path.isfile(creds_path)
        config.read(creds_path)
        key = config.get('credentials', 'TREEBEARD_API_KEY')
        email = config.get('credentials', 'TREEBEARD_EMAIL')
        click.echo('Connecting to your account.')
    except:
        click.echo(f"No credentials found - please run: treebeard configure")
    return key, email


def firebase_auth(key, email):
    """Login or create account in a webpage"""
    # additional_claims = {
    #     'email': 'myemail@me.com'
    # }
    # custom_token = auth.create_custom_token('myapikey', additional_claims)

    # click.launch(
    #     f'https://treebeard.io/app/login?email={email}&key=&{key}')
    click.echo('Webpage launch')
    return


@click.group()
def cli():
    pass
    # click.echo('Debug mode is %s' % ('on' if debug else 'off'))


@cli.command()
@click.option('--email', prompt='Your email:')
@click.option('--key', prompt='Your API key:')
def configure(email, key):
    """ Set initial credentials"""
    set_credentials(email, key)

    # @cli.command()
    # def init():
    #     """Connect to Treebeard account (browser popup or CLI login)
    #     """
    #     # Check if local credentials exist
    #     key, email = fetch_credentials()
    #     # Authorise User Account with Firebase
    #     firebase_auth(key, email)
    #     click.echo(f'Account initialised for {email}, key: {key}')
    #     return


# @cli.command()
# @click.option('--file', '-f', 'filename', default=None, type=click.Path(exists=True),
#               help='Specify notebook to see logs')
# def logs(filename):
#     """
#     See all actions and deployment results
#     """
#     if filename:
#         click.echo(f'Historical deployments for {filename}:')
#     else:
#         click.echo('Historical deployments for all notebooks:')

@cli.command()
@click.option('t', '--hourly', flag_value='hourly', help='Run notebook hourly')
@click.option('t', '--daily', default=True, flag_value='daily', help='Run notebook daily')
@click.option('t', '--weekly', flag_value='weekly', help='Run notebook weekly')
@click.option('t', '--quarter-hourly', flag_value='quarter-hourly', help='Run quarter-hourly')
def run(t):
    """
    Run a notebook and optionally schedule it to run periodically
    """
    notebook_name = treebeard_env['notebook_id']
    endpoint = f"{remote_url}{notebook_name}"

    spinner = Halo(text='requesting run', spinner='dots')
    spinner.start()
    archive_filename = '/tmp/treebeard_upload.tgz'
    with tarfile.open(archive_filename, "w:gz") as tar:
        tar.add(os.getcwd(), arcname=os.path.basename(os.path.sep))

    response = requests.post(
        endpoint, files={'repo': open('/tmp/treebeard_upload.tgz', 'rb')})

    spinner.stop()

    json_data = json.loads(response.text)
    click.echo(f"Run has been accepted! {json_data['admin_url']}")


@cli.command()
def cancel():
    """Cancels the current notebook build and schedule"""
    notebook_name = treebeard_env['notebook_id']
    endpoint = f"{remote_url}{notebook_name}"

    spinner = Halo(text='cancelling', spinner='dots')
    click.echo(f"Cancelling {notebook_name}")
    spinner.start()
    requests.delete(endpoint)
    spinner.stop()
    click.echo(f"cancelled {notebook_name}!`")


@cli.command()
def status():
    """Show the status of the current notebook"""
    notebook_name = treebeard_env['notebook_id']
    endpoint = f"{remote_url}{notebook_name}"

    response = requests.get(endpoint)
    json_data = json.loads(response.text)
    click.echo(f"Notebook: {notebook_name}")
    if len(json_data) == 0:
        click.echo(
            'This notebook has not been run. Try running it with `treebeard run`')
        return
    click.echo('Recent runs:')
    for run in json_data:
        now = parser.isoparse(datetime.datetime.utcnow().isoformat() + 'Z')
        start_time = parser.isoparse(run['start_time'])
        time_string = timeago.format(start_time, now=now)
        click.echo(f"{run['url']} {time_string}")


@cli.command()
def version():
    import pkg_resources  # part of setuptools
    version = pkg_resources.require("treebeard")[0].version
    click.echo(version)


@cli.command()
def info():
    click.echo(treebeard_env)
